.. -*- coding: utf-8 -*-

.. _Part3:

--------------
Administration
--------------

This part is for installation and administration of the *CubicWeb* framework and
instances based on that framework.

.. toctree::
   :maxdepth: 1
   :numbered:

   setup
   setup-windows
   config
   cubicweb-ctl
   create-instance
   instance-config
   site-config
   multisources
   ldap
   pyro
   migration
   additional-tips
   rql-logs

